@@ -26,9 +26,9 @@ Use any or combination of these styles in markdown blocks or `css_class` argumen
  `block`            | Block of text/objects {: .block}
  `block-[color]`    | Block of text/objects with specific background color from <br> red, green, blue, yellow, cyan, magenta and gray.
  `raw-text`         | Text will be shown as printed style. {: .raw-text}
- `zoom-self`        | Zooms object on hover, when Zoom is enabled. {: .zoom-self}
- `zoom-child`       | Zooms child object on hover, when Zoom is enabled.
- `no-zoom`          | Disables zoom on object when it is child of 'zoom-child'.
+ `focus-self`       | Double-click on element to zoom into popup view. Double-click again or press close button to exit. {: .focus-self}
+ `focus-child`      | Focus on child objects of node with this class. Same double-click to zoom in/out behavior.
+ `no-focus`         | Disables focus on object when it is a direct child of 'focus-child'.
 
 Besides these CSS classes, you always have `Slide.set_css`, `Slides.html('style',...)` functions at your disposal.
 '''
@@ -40,9 +40,11 @@ Extended syntax on top of [Python-Markdown](https://python-markdown.github.io/)
 
 **Presentation Structure**{{.text-big}}
 
-Slides & Frames Separators
+Slides, Pages and Parts Separators
 : Triple dashes `---` is used to split text in slides inside markdown content of `Slides.build` function or markdown file.
-Double dashes `--` is used to split text in frames. Alongwith this `%++` can be used to increment text on framed slide.
+Double dashes `--` (`PAGE` in Python) is used to split text in pages. Double plus `++` (`PART` in Python) can be used to increment objects in parts on slide/page.
+A `++` on its own line before `columns/multicol` block will make it reveal content incrementally, provided that columns are separated by `+++`.
+The combinations of pages and parts create frames on slides. Note that only `++` allows content on same line after it and following lines.
 
 Sections & TOC
 : alert`section\`content\`` to add a section that will appear in the table of contents.
@@ -57,7 +59,7 @@ These files are watched for edits if included in synced markdown file via `Slide
 
 Citations
 : - alert`cite\`key1,key2\`` / alert`\@key1,\@key2` to add citation to current slide. citations are automatically added in suitable place and should be set once using `Slides.set_citations` function (or see below).
-- With citations mode set as 'footnote', you can add alert`refs\`ncol_refs\`` or code`Slides.refs` to add citations anywhere on slide. If `ncol_refs` is not given, it will be picked from layout settings.
+- With citations mode set as 'footnote', you can add alert`refs\`ncol_refs\`` or code` Slides.refs ` to add citations anywhere on slide. If \`ncol_refs\` is not given, it will be picked from layout settings.
   Using alert`refs\`ncol_refs, key1, key2,...\`` will show only citations for given keys on that place. It is useful on slides with frames to show relevant citations on each frame.
 - Force a citation to be shown inline by appending a ! even in footnote mode, such as alert`\@key!` or alert`cite\`key1,key2!\``.
 - In the synced markdown file (also its included files) through `Slides.sync_with_file`, you can add citations with block sytnax:                             
@@ -89,14 +91,19 @@ The general block syntax is `::: type-or-classes [args] attributes`.
     | Block Syntax      | Description                                                                                                 |
     |:----------------- |:----------------------------------------------------------------------------------------------------------- |
     | `::: raw/pre`     | Raw text or preformatted text, no markdown parsing. Use `raw` or `pre` as first word in block. |
-    | `::: code `       | Code block with syntax highlighting, parameters are passed to highlight function. |
+    | `::: code [focused lines]`  | Code block with syntax highlighting, parameters are passed to highlight function. |
     | `::: tag or classes` | tags are block level elements such as `p`, `details`, `summary`, `table`, `center`, etc. |
     | `::: columns/multicol [widths]` | Create columns with relative widths, e.g. `columns 4 6` for 40% and 60% width. Use `+++` separator to reveal content incrementally/make display columns. |
-    | `::: md-[pos]` | Parse markdown in the block, with showing source code at `pos=[before,after,left,right]`. Add `-c` to collapse code and show on click. |
+    | `::: md-[before,after,var_name] [focused lines]` | Parse markdown in the block, with showing source code at before or after or assign a variable name and use anywhere you want, e.g. \%{{var_name.collapsed}} |
     | `::: table [col widths]` | Create a table with optional column widths, e.g. `::: table 1 2` for 33% and 66% width. Use `caption-side=top/bottom` to place caption on top/bottom.|
     | `::: citations [inline or footnote]` | Add citations in the block, with `inline` or `footnote` mode. Use `\@key: value` syntax to add citations in block. |
     | `::: display css_classes` | Create a block with specific CSS classes forcing display mode, it can break dom flow, but usefull to embed widget variables under blocks. |
 
+::: details
+    ::: summary | Important Notes on `md-` and `code` blocks
+    - Variable created with `md-var_name` can be used anywhere in markdown using alert`\%{{var_name}}` syntax and take precendence over Python scope variables.
+    - `md-[position or variable]` accepts same parameters as `code` block for syntax highlighting, but additionally can access properties in \%{{var}} such as \%{{var.inline}}, \%{{var.collapsed}} etc.
+    - Both `code` and `md-var` blocks support attribute access such as `::: code.collapsed` or `::: md-var.inline` to show selected view. You can also use `::: code 1 3` to focus on specific lines based on index 1 in markdown unlike Python.
 ---
 
 **Layouts**{{.text-big}}
@@ -106,13 +113,13 @@ Inline Columns
 
 Block Columns
 : You can create columns using `::: columns` or `::: multicol` syntax. 
-Column separator is triple plus `+++` if intended in display mode.
+Column separator is triple plus `+++` if intended in display mode and should be a `++` before block to make it incremental.
 
 ```md-before
 ::: columns 6 1 4 block-blue 
 : border="1px dashed red"
     ::: block-red
-        - `::: columns/muticol` with a +++ separator act like `write` command and reveal content incrementally when `%++` is used
+        - `::: columns/muticol` with a +++ separator act like `write` command and reveal content incrementally when `++` is used before block.
         - children inside `columns` picks relative width from parent's `columns` block evem if '+++' is not used.
           In thise children should be visually blocks themselves like headings, paragraphs, lists etc or wrapped in `::: block` to make them obvious blocks like this one.
         - CSS classes and attributes can be used to style columns besides relative widths.
@@ -133,19 +140,29 @@ Inline Code
 : Inline code can be highlighted using alert`code\`code\`` syntax, e.g. color`code\`print('Hello')\`` → code`print('Hello')`.
 
 Code Blocks
-: Use standard markdown fenced code blocks or `::: code` blocks for syntax highlighting.
+: Use standard markdown fenced code blocks or `::: code ` blocks for syntax highlighting.
 
-```md-left
+```md-src
+::: columns
+    %{{src}}
+    +++
     ```python
     print('Hello, I was highlighted from a code block!')
     ```
-    
-    ::: code language=bash name=Shell lineno=False style=vim
+    ::: code 2 language=bash name=Shell lineno=False style=vim
         echo "Hello, I was highlighted from a code block!"
         ls -l | grep ".py" | wc -l
-```  
-- In ` ::: code ` block, you need to set parameters that are passed to `code` function, such as `language`, `name`, `lineno`, `css_class`, etc.
-- The \`\`\` code block does act like `::: code ` block and supports same parameters.
+``` 
+
+```md-src.collapsed
+::: details
+    ::: summary | Click to see important notes on code blocks 
+    - In ` ::: code ` block, you need to set parameters that are passed to `code` function, such as `language`, `name`, `lineno`, `css_class`, etc.
+    - The \`\`\` code block does act like `::: code ` block and supports same parameters.
+    - You can focus on specific lines in code blocks using line numbers (1-based) such as `::: code 2 4 5` to focus on lines 2, 4 and 5 visually. 
+    - You can also use `::: code.collapsed` or `::: code.inline` to show collapsed or inline view of code block respectively.
+    %{{src}}
+```
 
 ---
 
@@ -189,13 +206,16 @@ Functions (that can also take extra args [python code as strings] as alert`func[
     This should be rarely used when your markdown contains a lot of $ \LaTeX $ equations to avoid excessively escaping them with curly braces in favor of few escaped variables.
 
 Upto 4 level nesting is parsed in inline functions using (level + 1) number of alert`/` (at least two) within backticks in functions given below. 
-```md-left
-stack[(6,4),css_class="block-blue"]`////
-    This always parse markdown in `returns=True` mode. ||
-    stack[css_class="info"]`/// B ||
-        color["skyblue"]`//alert`Alerted Text` Colored Text //`
-    ///` 
-////`
+```md-src_var
+::: columns
+    %{{src_var}}
+    +++
+    stack[(6,4),css_class="block-blue"]`////
+        This always parse markdown in `returns=True` mode. ||
+        stack[css_class="info"]`/// B ||
+            color["skyblue"]`//alert`Alerted Text` Colored Text //`
+        ///` 
+    ////`
 ```
 
 ---
@@ -209,11 +229,14 @@ stack[(6,4),css_class="block-blue"]`////
 - Use `_\`sub\`` and `^\`sup\``  for subscript and superscript respectively, e.g. H_`2`O, E = mc^`2`.
 - See `Slides.css_styles` for available CSS classes to use in markdown blocks and other places.
 - Definition list syntax:
-```md-left
-Item 1 Header
-: Item 1 details ^`1`
-Item 1 Header
-: Item 1 details _`2`
+```md-src
+::: columns
+    %{{src}}
+    +++
+    Item 1 Header
+    : Item 1 details ^`1`
+    Item 1 Header
+    : Item 1 details _`2`
 ```
 
 **Extending Syntax**{{.text-big}}
