@@ -40,11 +40,11 @@ slides = isd.Slides()
 
 ```python
 with slides.build(-1):
-    print("I will be on all frames in any case")
-    slides.fsep()
+    print("I will be first item shown!")
+    slides.PART()
     print("-1 will pick latest slide number!")
-    slides.fsep(stack=True)
-    print("I will be incremented to previous content becuase stack=True in line above!")
+    slides.PART()
+    print("I will be last item shown on current page!")
 ```
 
 ```python
@@ -77,34 +77,35 @@ def _key(k): # other properties in CSS
 
 
 key_maps = {
-    "▸, Space": "Next slide",
-    "◂, Ctrl + Space": "Previous slide",
-    "Z": "Toggle objects zoom mode",
+    "▸, +, Space": "Next slide",
+    "◂, -": "Previous slide",
+    "L": "Toggle LASER pointer",
     "P": "Print PDF of slides",
     "F": "Toggle fullscreen",
     "Esc": "Exit fullscreen",
     "S": "Toggle settings panel",
-    "L": "Toggle LASER pointer",
     "E": "Edit Source Cell/View Variables", 
     "K": "Show keyboard shortcuts",
 }
 
-key_combs = f"""
+key_combs = f"""color['var(--accent-color)']`Move cursor/airmouse to left/right edge and click.`
+
 | Shortcut                                    | Button                                            | Action                 | 
 |:--------------------------------------------|---------------------------------------------------|:-----------------------|
-| {_key('&#9141;')}/{_key('▸')}               | {_icons["chevronr"]}                              | Move to next slide     |
-| {_key('Ctrl')} + {_key('&#9141;')}/{_key('◂')} | {_icons["chevronl"]}                           | Move to previous slide |
-| {_key('Ctrl')} + {_key('0')}/{_key('0')}    | {_icons['arrowbl']}/{_icons['arrowbr']}       | Jump to Star/End of slides |
-| {_key('Ctrl')} + {_key('[1-9]')}/{_key('[1-9]')} | <none>                                      | Shift [1-9] slides left/right |
-| {_key('Z')}                                 | {_icons["zoom-in"]}, {_icons["zoom-out"]}         | {key_maps["Z"]}        |
-| {_key('F')}                                 | {_icons["expand"]}, {_icons["compress"]}          | {key_maps["F"]}        |
-| {_key('Esc')}                               |    <none>                                                | {key_maps["Esc"]}      |
-| {_key('S')}                                 | {_icons["settings"]}, {_icons["close"]}           | {key_maps["S"]}        |
+| {_key('▸')} / {_key('+')} / {_key('&#9141;')}   | {_icons["chevronr"]}                          | Move to next slide     |
+| {_key('◂')} / {_key('-')}                   | {_icons["chevronl"]}                              | Move to previous slide |
+| {_key('*')}, {_key('/')}                    | <none>                                 | Fast forward/backward by 5 slides |
 | {_key('E')}                                 | {_icons["code"]}                                  | {key_maps["E"]}        |
+| {_key('Esc')}                               |    <none>                                         | {key_maps["Esc"]}      |
+| {_key('F')}                                 | {_icons["expand"]}, {_icons["compress"]}          | {key_maps["F"]}        |
+| {_key('K')}                                 | {_icons["keyboard"]}                              | {key_maps["K"]}        |
 | {_key('L')}                                 | {_icons["laser"]}, {_icons["circle"]}             | {key_maps["L"]}        |
-| {_key('K')}                                 |      <none>                                              | {key_maps["K"]}        |
-| {_key('Ctrl')} + {_key('P')}                |      <none>                                              | {key_maps["P"]}        |
-| {_key('Ctrl')} + {_key('Alt')} + {_key('P')}|      <none>                                     | {key_maps["P"]} (merged frame)|
+| {_key('S')}                                 | {_icons["panel"]}, {_icons["close"]}              | {key_maps["S"]}        |
+| {_key('Ctrl')} + {_key('P')}                |      <none>                                       | {key_maps["P"]}        |
+| {_key('Ctrl')} + {_key('Alt')} + {_key('P')}|      <none>                                | {key_maps["P"]} (merged frame)|
+
+- color['var(--fg3-color)']`{_key('+')}, {_key('-')},{_key('*')}, {_key('/')}, keys enable full numpad-only navigation.`
+- color['var(--fg3-color)']`//Double-click on images/plots and focusable elements (see `Slides.css_styles`) to zoom into focused view.//`
 """ 
 
 how_to_print = f"""
@@ -115,6 +116,7 @@ Use `Save as PDF` option instead of Print PDF in browser to make links work in o
 ::: note-warning
     - PDF printing is experimental and may not work as expected in all browsers and tested only in JupyterLab.
     - In case of issues with frames not displaying properly using `Ctrl + P`, try `Ctrl + Alt + P` to fallback to merged frames.
+    - Make sure your presentation is clean for print. "Inline Notes" are only meant for personal reference or sharing slides with notes.
 
 **Printing from Exported HTML File**<br>
 You can also get PDF from exported HTML file. Use `Save as PDF` and enable background graphics when printing to keep links working.
@@ -125,7 +127,7 @@ into Clips GUI in side panel. On Linux, you need alert` xclip ` or alert`wl-past
 
 ::: note-tip
     - You might want to reflow content for export purpose. Use checkbox in settings panel to enable it.
-    - In case of Inherit theme selected, you can ensure Jupyterlab colors in exported HTML by rerunning `export_html` or reclicking export button.
+    - Print slides with notes by enabling `Inline Notes` option in settings panel before print/export. Notes appear at top to grab immediate attetion of the speaker.
 """
 more_instructions = f"""{get_logo('2em', 'IPySlides')}
 ::: note-tip
