@@ -1,6 +1,6 @@
 """Slide Object, should not be instantiated directly"""
 
-import time, textwrap
+import textwrap
 from contextlib import contextmanager, suppress
 from functools import wraps
 from IPython.display import display
@@ -78,7 +78,7 @@ class Vars:
 
 class Slide:
     "Slide object, should not be instantiated directly by user."
-    _animations = {'main':'slide_h','frame':'appear'}
+    _animations = {'main':'slide_h','page':'appear'}
     _overall_css = ''
     def __init__(self, app, number):
         self._widget = _Output(layout = dict(margin='auto',padding='16px', visibility='hidden')).add_class("SlideArea")
@@ -112,7 +112,7 @@ class Slide:
         self.__dict__[name] = value
     
     def _set_defaults(self):
-        for attr in ['_on_load', '_on_exit', '_fsep']:
+        for attr in ['_on_load', '_on_exit', '_fsep_legacy']:
             if hasattr(self, attr):
                 delattr(self, attr) # reset these attributes if any
     
@@ -125,11 +125,11 @@ class Slide:
         self._has_vars = () # Update in _slide function for markdown slides only
         self._source = {'text': '', 'language': ''} # Should be update by Slides
         self._split_frames = True
-        self._has_top_frame = True
         self._set_refs = True
         self._toc_args = () # empty by default
-        self._widget.add_class(f"n{self.number}").remove_class("base") # will be added by fsep
+        self._widget.add_class(f"n{self.number}").add_class("base") # base is needed to distinguisg clones during printing where it is removed
         self._tcolors = {} # theme colors for this slide only
+        self._fcss = ipwHTML(layout={"margin": "0","padding": "0","heigh": "0"}) # frame separator CSS
   
     def _set_source(self, text, language):
         "Set source code for this slide. If"
@@ -152,7 +152,7 @@ class Slide:
             elif cap.stderr:
                 raise RuntimeError(f'func in on_load(func) raised an error. See above traceback!')
         
-        # This should be outside the try/except block even after finally, if successful, only then assign it.
+        # This should be itemside the try/except block even after finally, if successful, only then assign it.
         self._on_load = func # This will be called in main app
     
     def _run_on_load(self):
@@ -182,9 +182,6 @@ class Slide:
         
         with self._app._set_running(self):
             with capture_content() as captured:
-                display(html('span', '', id = self._sec_id, css_class='Slide-UID'), # span to not occupy space, need to remove from frames later.
-                    metadata={'skip-export':'export html assign itself'})  # to register section id in DOM
-                display(self._alt_print, metadata={'skip-export':'export html takes css itself'}) # alternate print content if any should be on top frame
                 yield captured
             
             if (self.number == 0) and self._fidxs:
@@ -197,12 +194,33 @@ class Slide:
                 else:
                     raise RuntimeError(f'Error in building {self}: {captured.stderr}')
             
-            self._contents = captured.outputs
+            outputs = self._handle_fsep_legacy(captured.outputs) # handle old frame separators if any before skipping trails 
+            # Skip trailing delimiters (PAGE or PART) from the end, or empty capture
+            stop = len(outputs)
+            for i in range(stop - 1, -1, -1):
+                out = outputs[i]
+                metadata = getattr(out, 'metadata', None)
+                delim = metadata.get("DELIM", None) if metadata and isinstance(metadata, dict) else None
+                if delim in ("PAGE", "PART") or set(out.data.keys()) == {'text/plain'}:  # Check if DELIM exists or empty content
+                    stop -= 1
+                    continue
+                break # Found non-delimiter / non-empty content, stop here
+            
+            self._contents = captured.outputs[:stop]
             self._set_css_classes(remove = 'Out-Sync') # Now synced
             self.update_display(go_there=True)    
 
             if self._app.widgets.checks.focus.value: # User preference
                 self._app._box.focus()
+    
+    def _handle_fsep_legacy(self, contents):
+        if getattr(self, '_fsep_legacy', False):
+            for c in contents:
+                if isinstance(c.metadata, dict) and "DELIM" in c.metadata:
+                    new_delim = "PAGE" if self._split_frames else "PART"
+                    if c.metadata["DELIM"] != "ROW": # allow explict setting in fsep for backward compatibility, except rows
+                        c.metadata["DELIM"] = new_delim
+        return contents
         
     def update_display(self, go_there = True):
         "Update display of this slides including reloading citations, widgets etc."
@@ -213,8 +231,22 @@ class Slide:
             self._set_css_classes('SlideArea', 'SlideArea') # Hard refresh, removes first and add later
         else:
             self._widget.clear_output(wait = True) # Clear, but don't go there
-    
+        
+        # Need to know how many contents before user provide content
+        with capture_content() as cap:
+            # show speaker notes at top if any to grab immediate attention of speaker, will be shown only in PDF.
+            self._speaker_notes(returns=False) # displays directly if any
+            display(
+                html('span', '', id = self._sec_id, css_class='Slide-UID'), # span to not occupy space, need to remove from frames later.
+                self._alt_print, # alternate print content such as CSS and bg image
+                self._fcss, # frame separator CSS
+                metadata={'skip-export':'export html assign itself'}
+            )  # to register section id in DOM
+            
+        self._offset = len(cap.outputs) # to offset frames later, store for export
+                
         with self._widget:
+            display(*cap.outputs) # speaker notes and metadata stuff as top
             for obj in self.contents:
                 display(obj)
                 if hasattr(obj, 'update_display'): 
@@ -225,7 +257,7 @@ class Slide:
                 self._handle_refs()
             
         # after others to take everything into account
-        self._reset_frames()
+        self._reset_frames(offset = self._offset)
         self._app._update_toc()
     
     def _rebuild(self, go_there=False):
@@ -278,55 +310,82 @@ class Slide:
             data = {'text/plain': title,'text/html': self._app.html('div', [title, ol]).value},
             metadata = {"DataTOC": self.number}) # to access later
     
-    def _reset_frames(self):
-        nc_frames, contents = [], self.contents  # get once
-        for i, c in enumerate(contents):
-            if "FSEP" in c.metadata:
-                if i > 0: # ignore first separator without content before
-                    if "COLUMNS" in contents[i-1].metadata: # last before frame separator, keep poistive index
-                        nc_frames.append((i, len(contents[i-1]._cols)))
-                    else: 
-                        nc_frames.append(i+1)
-                elif not self.stacked: # User may not want to add content on each frame
-                    nc_frames.append(0) # avoids creating a frame with no content
-                    self._has_top_frame = False # reset by each run
-            
-        else: # Handle content after last frame
-            if nc_frames: # Do not add if no frames already
-                if "COLUMNS" in contents[-1].metadata:
-                    nc_frames.append((len(contents), len(contents[-1]._cols)))
-                
-                if isinstance(nc_frames[-1],int): # safely add full
-                    nc_frames[-1] = len(contents)
-        
-        new_frames = []
-        for f in nc_frames:
-            if isinstance(f,tuple):
-                for k in range(f[1]): 
-                    new_frames.append((f[0], k+1)) #upto again
-            elif not f in new_frames: # avoid duplicates at end
-                new_frames.append(f)
-        
-        
-        if not self.stacked:
-            new_frames = [0, *[f[0] + 1 if isinstance(f, tuple) else f for f in new_frames]] # column was at index, get upto for range
-            new_frames = [range(i,j) for i,j in zip(new_frames[:-1], new_frames[1:]) if range(i,j)] # as range, non-empty only
-            
-            if len(new_frames) > 1:
-                self._frame_idxs = tuple(new_frames[1:]) # first join on all
-                self._frame_top = new_frames[0].stop
-            else:
-                self._frame_idxs = ()
-        else:
-            self._frame_idxs = tuple(new_frames[1:]) # join first content here as well to make same number of fames
 
+    def _reset_frames(self, offset=0):
+        frames, contents = [], self.contents  # get once
+        pages = [
+            i for i, c in enumerate(contents) 
+            if isinstance(c.metadata, dict) and 
+            c.metadata.get("DELIM","") == "PAGE"
+        ]  # find page delimiters
+        
+        if pages:
+            pages = [{"head": pages[0] - 1, "start": p, "end": (pages[i+1] if (i+1) < len(pages) else len(contents)) - 1} for i, p in enumerate(pages)]
+        else:
+            pages = [{"head": -1, "start": 0, "end": len(contents) - 1}] # One page by default
+        
+        for ip, page in enumerate(pages):
+            # Parts inside head only take effect on first frame
+            start = 0 if ip == 0 and page["head"] > -1 else page["start"]
+            if parts := self._resolve_parts(page, contents, range(start, page["end"] + 1)):
+                parts[0]["anim"] = "next" # add animation flag to first part while navigative forward
+                parts[-1]["anim"] = "prev" # add animation flag to last part while navigative backward
+                frames.extend(parts)
+            else:
+                frames.append({**page, "anim": "both"}) # no parts, single frame, animate both ways
+        
+        # Add offeset to all indices to keep metadata available across all frames
+        for i, frame in enumerate(frames):
+            for key in ("head", "start", "part", "end"):
+                if key in frame and isinstance(frame[key], int):
+                    frames[i][key] += offset
+        
+        self._frame_idxs = frames if len(frames) > 1 else ()
         if self._frame_idxs:
             self.first_frame() # Bring up first frame to activate CSS
-        else:
-            if hasattr(self, '_frame_idxs'): # from previous run may be
-                del self._frame_idxs
-            if hasattr(self, '_frame_add'):
-                del self._frame_top
+        elif hasattr(self, '_frame_idxs'): # from previous run may be
+            del self._frame_idxs
+        return frames
+    
+    def _resolve_parts(self, page, contents, indxs):
+        ensure_dict = lambda meta: meta if isinstance(meta, dict) else {} # insure dict type
+        frames = []
+        
+        for index in indxs:
+            meta = ensure_dict(contents[index].metadata)
+            if isinstance(meta, dict) and meta.get("DELIM", "") == "PART":
+                if index == indxs.stop - 1: 
+                    continue  # skip if PART is last in range
+                
+                meta_prev = ensure_dict(contents[index - 1].metadata) if index - 1 in indxs else {}
+                meta_next = ensure_dict(contents[index + 1].metadata) if index + 1 in indxs else {}
+                
+                # Single column flattened after PART with its ROW delimiters
+                if ("FLATCOL" in meta_next):
+                    for i in range(index, index + meta_next["FLATCOL"]):
+                        meta_row = ensure_dict(contents[i].metadata) if i in indxs else {}
+                        if meta_row.get("DELIM", "") == "ROW":
+                            meta_row["DELIM"] = "PART"  # change ROW to PART for frame handling
+                
+                # Check if PART is before COLUMNS to trigger increments
+                if "COLUMNS" in meta_next and not getattr(self, '_fsep_legacy', False):
+                    # PART before COLUMNS - trigger column incremental
+                    for part in contents[index + 1]._parts:
+                        frames.append({**page, "part": index + 1, **part})
+                elif getattr(self, '_fsep_legacy', False) and "COLUMNS" in meta_prev:
+                    # Legacy mode: PART after COLUMNS
+                    for part in contents[index - 1]._parts:
+                        frames.append({**page, "part": index - 1, **part})
+                else:
+                    if (meta_prev.get("DELIM","") == "PART" # PART adjacent to PART
+                        or (frames and "col" in frames[-1])): # PART adjacent to COLUMNS
+                        continue  # skip this PART as already handled
+                    frames.append({**page, "part": index}) # add stand alone PART normally
+        
+        if (frames and frames[-1].get("part", index) != index and 
+            meta.get("DELIM", "") != "PART"): # last PART not added
+            frames.append({**page, "part": index})
+        return frames       
     
     @property
     def _fidxs(self): return getattr(self, '_frame_idxs', ())
@@ -338,13 +397,20 @@ class Slide:
     
     def _update_view(self, which):
         self._set_progress()
-        if not self.stacked: # In case of incremental frames, only edge slides are animated automatically
+        # Determine if we should animate based on frame position and type
+        frame = self._fidxs[self.indexf] if self._fidxs else {}
+        anim = frame.get('anim', None)  # 'next', 'prev', or 'both'
+
+        # Only animate on appropriate edges
+        should_animate = anim == 'both' or anim == which
+    
+        if should_animate:
             if which == 'prev':
                 self._app.widgets.slidebox.add_class('Prev')
             else:
                 self._app.widgets.slidebox.remove_class('Prev')
             self._app._update_tmp_output(self.animation, self.css)
-        elif not self.indexf in (self.nf-1, 0):
+        else:
              self._app._update_tmp_output(self.css) # avoid animations between frames
 
         if self.index == self._app.wprogress.max: # This is last slide
@@ -359,7 +425,7 @@ class Slide:
             0 < self.indexf < (self.nf - 1)
         ]) and hasattr(self,'_on_load') and callable(self._on_load):
             self._on_load(self)
-    
+        
     def _frame_css(self, index):
         if not self._fidxs:
             return ''
@@ -367,25 +433,56 @@ class Slide:
         if index < 0 or index >= self.nf:
             raise IndexError(f"Frame index {index} out of range for slide {self.number} with {self.nf} frames!")
         
-        start, nrows, ncols, first = 1, self._fidxs[index], 0, getattr(self, '_frame_top',0)
-        if isinstance(nrows, tuple):
-            nrows, ncols = nrows
-        elif isinstance(nrows, range): # not joined
-            start, nrows = nrows.start, nrows.stop
-        
+        # Helper to hide/show elements with proper collapse
         def hide(b): 
-            props = {'^, ^ *':{'visibility': ('hidden' if b else 'inherit') + '!important'}} # hide all and nested
-            return props if self.stacked else {**collapse_node(b), '@media print': props}
-            
-        return _styled_css({ # base class is important to avoid CSS clashes while printing clones
-            f'^.n{self.number}.base > .jp-OutputArea > .jp-OutputArea-child': {
-                f'^:not(:nth-child(n + {start}):nth-child(-n + {nrows}))': hide(True), # start through nrows
-                f'^.jp-OutputArea-child.jp-OutputArea-child:nth-child(-n + {first})': hide(False), # initial objs on each, increase spacificity 
-                **({f'^:nth-child({nrows}) .columns.writer:first-of-type > div:nth-child(n + {ncols+1})': { # avoid nested columms
-                    'visibility': 'hidden !important', # enforce this instead of jumps in height
-                }} if isinstance(self._fidxs[index], tuple) else {}), 
-            },
-        }).value
+            return {'^, ^ *': {'visibility': ('hidden' if b else 'inherit') + '!important'}}
+        
+        def collapse(b):
+            return {**collapse_node(b), '@media print': hide(b)} # somehow needs invisibility in print, otherwise shows up
+
+        # Build CSS to show only current frame's content
+        frame = self._fidxs[index]
+        css_rules = {}
+
+        # head content visible everywhere
+        head_end = frame.get("head", -1) + 1 # CSS nth-child is 1-indexed
+        if head_end > 0:
+            css_rules[f'^:nth-child(-n + {head_end})'] = hide(False)
+        
+        # Collapse nodes between head and start
+        start = frame["start"] + 1
+        if head_end > 0 and start > head_end + 1:
+            css_rules[f'^:nth-child(n + {head_end + 1}):nth-child(-n + {start - 1})'] = collapse(True)
+        
+        # Collapse nodes after end
+        end = frame["end"] + 1
+        css_rules[f'^:nth-child(n + {end + 1})'] = collapse(True)
+
+        # Handle PART incremental frames
+        if "part" in frame:
+            part_end = frame["part"] + 1
+            css_rules[f'^:nth-child(n + {start}):nth-child(-n + {part_end})'] = hide(False)
+            # Hide content after part
+            if part_end < end:
+                css_rules[f'^:nth-child(n + {part_end + 1}):nth-child(-n + {end})'] = hide(True)
+
+            # Handle column incremental display
+            if "col" in frame:
+                col_idx = frame["col"]
+                # Within the PART output (which contains COLUMNS), hide columns after current one
+                col_sel = f'^:nth-child({part_end}) .columns.writer:first-of-type > div'
+                css_rules[f'{col_sel}:nth-child(n + {col_idx + 2})'] = hide(True)
+
+                if "row" in frame:
+                    # Hide rows after current one in the current column
+                    rows_hide = frame["row"] + 2 # +2 to start hiding after this row
+                    css_rules[f'{col_sel}:nth-child({col_idx + 1}) > .jp-OutputArea > .jp-OutputArea-child:nth-child(n + {rows_hide})'] = hide(True)
+
+        # Build final CSS with proper selector
+        base_selector = f'^.n{self.number}.base > .jp-OutputArea > .jp-OutputArea-child'
+        final_css = {base_selector: css_rules}
+    
+        return _styled_css(final_css).value
     
     def _show_frame(self, which):
         if self._fidxs:
@@ -396,12 +493,11 @@ class Slide:
             else:
                 return False
             
-            self._fsep.value = self._frame_css(self.indexf)
+            self._fcss.value = self._frame_css(self.indexf)
             self._update_view(which)
             return True # indicators required
         else:
-            if hasattr(self, '_fsep'):
-                del self._fsep
+            self._fcss.value = '' # clear frame css if any
             return False
     
     def next_frame(self):
@@ -412,13 +508,6 @@ class Slide:
         "Jump to previous frame and return True. If no previous frame, returns False"
         return self._show_frame('prev')
     
-    def _set_print_css(self, merge_frames = False):
-        if merge_frames:
-            if hasattr(self, '_fsep'):
-                self._fsep.value = '' # Just let free print go
-        elif hasattr(self, '_fsep'): 
-            self._fsep.value = self._frame_css(0) # set first frame for print mode without other actions
-            
     def _reset_indexf(self, new_index, func): 
         old = int(self.indexf) # avoid pointing to property
         self._indexf = new_index
@@ -439,6 +528,12 @@ class Slide:
         "Jump to last frame"
         return self._reset_indexf(self.nf, self.prev_frame) # go right and swicth back
     
+    def _set_print_css(self, merge_frames = False):
+        if merge_frames:
+            self._fcss.value = '' # Just let free print go
+        else: 
+            self._fcss.value = self._frame_css(0) # set first frame for print mode without other actions
+    
     def _set_progress(self):
         unit = 100/(self._app._iterable[-1].index or 1) # avoid zero division error or None
         value = round(unit * ((self.index or 0) - (self.nf - self.indexf - 1)/self.nf), 4)
@@ -459,6 +554,14 @@ class Slide:
                 css_class='Citations', style = '')
             self._refs.display()
     
+    def _speaker_notes(self, returns=False):
+        if self._notes:
+            out = html('div', self._notes, 
+                css_class='speaker-notes print-only'
+            ) # hidden in slides always, shown in print/export if enabled
+            return out.value if returns else display(out)
+        return ''
+    
     def show(self):
         "Show this slide in cell."
         out = _Output().add_class('SlideArea')
@@ -480,15 +583,6 @@ class Slide:
             }}''' # each frames get own yoffset, margin-top 0 is important to force top to take effect
         ).display() # height is important to avoid spilling padding of SlideArea
         
-    def stack_frames(self, b):
-        "If provided argument is True, frames are stacked in one slide top to bottom incrementally, otherwise shown individually."
-        self._split_frames = bool(not b)
-    
-    @property
-    def stacked(self):
-        "Returns True if frames in slide are stacked incrementally, otherwise False."
-        return not self._split_frames
-        
     @property
     def notes(self): return self._notes
     
@@ -520,7 +614,7 @@ class Slide:
     
     @property
     def animation(self):
-        key = 'frame' if self._fidxs else 'main'
+        key = 'page' if self._fidxs else 'main'
         return html('style', self._animation or self._animations[key])
     
     @property
@@ -581,9 +675,9 @@ class Slide:
         return self._app.html('style', _build_css((klass,), props))
     
     def _set_alt_print(self):
+        self._alt_print.value = '' # reset first to recieve new content
         alt = f'{self._css}' # XTML or str
-        if self._bg_ikws.get('src',None):
-            alt += self._get_bg_image(get_unique_css_class()) # get bg image for print and dispaly behind slides
+        alt += self._get_bg_image(get_unique_css_class()) # get bg image for print and dispaly behind slides
         self._alt_print.value = alt
     
     def set_css(self, this: dict=None, overall:dict=None, **theme_colors):
@@ -642,19 +736,18 @@ class Slide:
         # We only store keywords to save memory and send image on javascript side for quick loading of images and printing
         self._bg_ikws = {
             'src': src, 'opacity': opacity, 'filter': filter, 'contain': contain, 
-            '_id': f"bgi-uid{self.number}", # for unique filters and styles
+            'uclass': self._sec_id, # for unique filters and styles
         } # store for export etc
         
-        if src is not None:
-            self._set_alt_print() # update alternate print-only content
-            if not self._contents:
-                self.set_css({}) # Remove empty CSS
-            self._app.widgets.iw.msg_tojs = 'SetIMG' # if it not happens to be there yet, will be done on swicthing slides
-            self._app.navigate_to(self.index) # Go there to see effects
+        self._set_alt_print() # update alternate print-only content
+        if not self._contents:
+            self.set_css({}) # Remove empty CSS
+        self._app.widgets.iw.msg_tojs = 'SwitchView' # enforces js to load background image, does not work otherwise
+        self._app.navigate_to(self.index) # Go there to see effects
     
     def _get_bg_image(self, selector):
         if (image := self._app.settings._resolve_img(self._bg_ikws.get('src',None), '100%')):
-            return f'''<div id="{self._bg_ikws['_id']}" class="BackLayer print-only">
+            return f'''<div class="BackLayer print-only {self._bg_ikws['uclass']}">
             <style>
                 {background_css(selector, **{k:v for k,v in self._bg_ikws.items() if k != 'src'})}
             </style>
@@ -667,10 +760,10 @@ class Slide:
             raise KeyError(f'animation {name!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
         return styles.animations[name].replace('.SlideBox',f'.{self._app.uid} .SlideBox')
             
-    def set_animation(self, this=None, main = None,frame = None):
-        "Set animation of this slide. Provide None if need to stop animation. Use `main` and `frame` to set animation to all slides."
+    def set_animation(self, this=None, main = None, page = None):
+        "Set animation of this slide. Provide None if need to stop animation. Use `main` and `page` to set animation to all slides and pages."
         self.__class__._animations['main'] = '' if main is None else self._instance_animation(main)
-        self.__class__._animations['frame'] = '' if frame is None else self._instance_animation(frame)
+        self.__class__._animations['page'] = '' if page is None else self._instance_animation(page)
         self._animation = '' if this is None else self._instance_animation(this)
         # See effect of changes
         if not self._app.this: # Otherwise it has side effects
