@@ -16,7 +16,7 @@ def demo_slides(slides):
 
     # title slide should alway be overwritten by 0 
     slides.build(0, """
-    ```md-after -c
+    ```md-src
     # Creating Slides
     ::: align-center width=50%
         alert`Abdul Saboor`^`1`, Unknown Author^`2`
@@ -27,7 +27,9 @@ def demo_slides(slides):
     
     ::: display align-center               
         vspace`2`Read instructions by clicking on %{btn} or same button in quick menu
-    ```""", btn = slides.widgets.buttons.info)
+    ```
+    %{src.collapsed}
+    """, btn = slides.widgets.buttons.info)
     
     # build_ is same as build(-1)
     slides.build_(f"""
@@ -76,7 +78,7 @@ def demo_slides(slides):
             with plt.style.context('ggplot'):
                 fig, ax = plt.subplots(figsize=(3.4,2.6))
                 _ = ax.plot(x,np.cos(x))
-            slides.write(ax, s.focus_lines([0,3,4]))
+            slides.write(ax, s.focus([0,3,4]))
 
 
     # Plotly and Pandas DataFrame only show if you have installed
@@ -188,14 +190,14 @@ def demo_slides(slides):
         slides.write("## Animating Matplotlib!", skipper.origin)
 
         with slides.code.context(returns = True) as s:
-            for idx in slides.fsep.iter(range(10,19)):
+            for idx in slides.PAGE.iter(range(10,19)):
                 fig, ax = plt.subplots(figsize=(3.4,2.6))
                 x = np.linspace(0,idx,50)
                 ax.plot(x,np.sin(x))
                 ax.set_title(rf'$f(x)=\sin(x)$, 0 < x < {idx+1}')
                 ax.set_xlim([0,18])
                 ax.set_axis_off()
-                slides.write(s.focus_lines([idx - 10]),ax,widths=[60,40])
+                slides.write(s.focus([idx - 10]),ax,widths=[60,40])
 
                 if idx == 10:
                     slides.write('Unlike `interact/interactive`, this animation is based on slide frames, all of which are exported to HTML.',css_class='note-tip')
@@ -206,26 +208,24 @@ def demo_slides(slides):
     boxes = [slides.html('h1', f"{c}",style="background:var(--bg3-color);margin-block:0.05em !important;") for c in range(1,5)]
     with slides.build(-1) as s:
         slides.write('# Default Frames')
-        s.get_source().focus_lines([2,3]).display()
-        slides.fsep()
-        for item in slides.fsep.iter(boxes):
+        s.get_source().focus([2,3]).display()
+        slides.PAGE() # want to show source alone first
+        for item in slides.PAGE.iter(boxes):
             slides.write(item)
 
     with slides.build(-1) as s:
-        slides.write('# Frames with \n#### code`fsep(stack=True)` and Fancy Bullet List yoffset`0`')
-        s.get_source().focus_lines([2,3,4]).display()
-        slides.fsep(stack=True) # setting True single time is enough
-
-        for item in slides.fsep.iter(boxes):
+        slides.write('# Frames with \n#### code`PAGE.iter()` and Fancy Bullet List yoffset`0`')
+        s.get_source().focus([2,3,4]).display()
+        slides.PAGE() # want to show source alone first
+        for item in slides.PAGE.iter(boxes):
             slides.bullets([item], marker='💘').display()
 
     with slides.build(-1) as s:
-        slides.write('# Frames with \n#### code`fsep.iter(stack=True)` and 2x2 grid of boxes yoffset`0`')
-        s.get_source().focus_lines(range(2,7)).display()
-        slides.fsep() # this time stack is in iter loop
+        slides.write('# Frames with \n#### code`PART.iter()` and 2x2 grid of boxes yoffset`0`')
+        s.get_source().focus(range(2,7)).display()
         objs = [boxes[:2],boxes[2:]]
         widths = [(1,3),(3,2)]
-        for ws, cols in slides.fsep.iter(zip(widths,objs),stack=True):
+        for ws, cols in slides.PART.iter(zip(widths,objs)):
             slides.write(*cols, widths=ws)
 
     # Youtube
@@ -275,7 +275,6 @@ def demo_slides(slides):
         s.get_source().display(True)
 
     slides.build(-1, r'''
-    %++
     ## $ \LaTeX $ in Slides
     Use `$ $` or `$$ $$` to display latex in Markdown, or embed images of equations
     $ \LaTeX $ needs time to load, so keeping it in view until it loads would help.
@@ -286,7 +285,8 @@ def demo_slides(slides):
         Varibale formatting alongwith $ \LaTeX $ alert`\%{var} → %{var}` is seamless.
     
     --
-    ::: md-after -c
+    ::: md-src
+        ++
         ```multicol 50 50
         $$ \int_0^1\\frac{1}{1-x^2}dx $$
         {.align-left .text-big .info}
@@ -295,6 +295,7 @@ def demo_slides(slides):
             $$ ax^2 + bx + c = 0 $$
             {.text-huge}
         ```
+    %{src.collapsed}
     ''', var = "'I was a variable'")
 
     with slides.build(-1) as some_slide:
