@@ -13,7 +13,8 @@ from IPython.display import display
 from IPython.utils.capture import capture_output
 from ipywidgets import DOMWidget
 
-from .formatters import XTML, altformatter, _highlight, htmlize, get_slides_instance, _inline_style
+from .formatters import XTML, altformatter, _highlight, htmlize, get_slides_instance, _inline_style, _delim
+from .source import SourceCode
 
 _md_extensions = [
     "tables",
@@ -70,7 +71,7 @@ _special_funcs = { # later functions can encapsulate earlier ones
     "iframe": "src",
     "details": "text or use ::: details block",
     "styled": "style objects with CSS classes and inline styles or use block ::: with css classes and props inline",
-    "zoomable": "zoom a node of html when hovered or used ::: zoom-self/zoom-child blocks",
+    "focus": "focus on a node of html when clicked or used ::: focus-self/focus-child blocks",
     "center": r"text or \%{variable} or use ::: center, ::: align-center blocks", # should after most of the functions
     "stack": r"text separated by || in inline mode, or use ::: columns block",
 }
@@ -282,7 +283,7 @@ class esc:
     
 
 # This shoul be outside, as needed in other modules
-def resolve_included_files(text_chunk):
+def resolve_included_files(parser, text_chunk):
     "Markdown files added by include`file.md[start:end]` should be inserted as plain."
     all_matches = re.findall(r"^(\s*)include\`(.*?)\`", text_chunk, flags=re.DOTALL | re.MULTILINE)
     for indent, match in all_matches:
@@ -315,7 +316,7 @@ def resolve_included_files(text_chunk):
                 text = textwrap.indent("\n" + "".join(lines) + "\n", indent) # need inside ::: blocks
                 text_chunk = text_chunk.replace(f"include`{match}`", text, 1)
         except Exception as e:
-            err_msg = error('Exception', f'Could not include file {filepath!r}:\n{e}').value
+            err_msg = error('Exception', f'Could not include file or markdown snippet {filepath!r}:\n{e}').value
             text_chunk = text_chunk.replace(f"include`{match}`", err_msg, 1)
 
     return text_chunk
@@ -323,6 +324,8 @@ def resolve_included_files(text_chunk):
 _extensions = Extensions() # Global instance of Extensions, don't delete class Extensions still
 
 class XMarkdown(Markdown):
+    _md_ns = {} # md-<var> stored here, stays across calls in session
+    
     def __init__(self):
         super().__init__(**_extensions.active)
         self._vars = {}
@@ -375,17 +378,24 @@ class XMarkdown(Markdown):
                 blocks.extend(self._split_blocks_with_dedent(text))  # split by :::
             elif len(parts := text.split('\n', 1)) == 2 and parts[1].strip():
                 blocks.append(("block", parts))  # ``` blocks, avoid empty blocks
-
+        
         outputs = []
-        for typ, obj in blocks:
+        for i, (typ, obj) in enumerate(blocks):
             if typ == "block":
+                if i > 0 and blocks[i-1][0] == "raw": # if previous was raw, pick if parts trigger was there
+                    obj = (*obj, True if blocks[i-1][1].strip().splitlines()[-1:] == ['++'] else False)  # this makes sure ++ starts at new line before block 
                 outputs.extend(self._parse_block(*obj))  # vars are substituted already inside, obj = (header, data)
             elif content := obj.strip():  # raw text but avoid empty stuff
-                out = self.convert(content) 
-                if isinstance(out, list):
-                    outputs.extend(out)
-                elif out: # Some syntax like section on its own line can leave empty block later
-                    outputs.append(XTML(out))
+                parts = list(self._split_parts(content))
+                for n, part in enumerate(parts, start=1):
+                    out = self.convert(part) 
+                    if isinstance(out, list):
+                        outputs.extend(out)
+                    elif out: # Some syntax like section on its own line can leave empty block later
+                        outputs.append(XTML(out))
+
+                    if not self._returns and n < len(parts):  # only add delim if displaying directly
+                        outputs.append(_delim("PART"))
         
         if not self._nesting_depth: # we need to keep these if nested parsing
             self._vars = {} # reset at end to release references
@@ -402,10 +412,17 @@ class XMarkdown(Markdown):
         else:
             return display(*outputs)
         
+        
+    def _split_parts(self, content):
+        yield from ( # split by ++ starting on its own line followed by one space charactor or till end of line
+            chunk for chunk in re.split(r'^\+\+(\s*$|\s)', content, flags=re.MULTILINE)
+            if chunk.strip() # avoid empty chunks
+        )  # split by ++ on its own line aggressively, but keep text on line as part of chunk
+        
     def _parse_params(self, param_string):
         """Parse parameter string with simple regex."""
         RE_PARAM = re.compile(
-            r'(?:([\w\-]+)=)?'
+            r'(?:([\w\-.]+)=)?'
             r'("([^"]*)"|\'([^\']*)\'|([\S]+))'
         )
         numbers, args, kwargs, node_attrs = [], [], {}, {}
@@ -427,13 +444,15 @@ class XMarkdown(Markdown):
                 if value.isdigit() or re.match(r'^\d+(\.\d+)?$', value):
                     numbers.append(float(value) if '.' in value else int(value))
                 else:
-                    args.append(value.replace('.',' ').strip()) # remove . from classes
+                    args.append((value.replace('.',' ') if args else value).strip()) # remove . from classes except from directive name
         sizes = numbers if numbers else None # making None is important for multicol and stack 
         # flatten node_attrs to a string, but not css properties
         node_attrs = ' '.join(f'{k}="{v}"' for k, v in node_attrs.items())
+        
         if args:
-            return args[0], sizes, ' '.join(args[1:]), kwargs, node_attrs # block type, sizes, className, css_props, node_attrs
-        return '', sizes, '', kwargs, node_attrs
+            typ, prop = args[0].split('.',1) if '.' in args[0] else (args[0], '')
+            return typ, prop, sizes, ' '.join(args[1:]), kwargs, node_attrs # block type, sizes, className, css_props, node_attrs
+        return '', '', sizes, '', kwargs, node_attrs
 
     
     def _split_blocks_with_dedent(self, text):
@@ -500,10 +519,10 @@ class XMarkdown(Markdown):
             text_chunk = re.sub(rf"\`{op}(.*?){cl}\`", repl, text_chunk, flags=re.DOTALL | re.MULTILINE)
         return text_chunk
 
-    def _parse_block(self, header, data):
+    def _parse_block(self, header, data, parts=False):
         "Returns list of parsed block or columns or code, input is without ``` but includes langauge name."
-        data = resolve_included_files(textwrap.dedent(data)) # clean up data  before processing 
-        typ, widths, _class, css_props, attrs = self._parse_params(header)
+        data = resolve_included_files(self, textwrap.dedent(data)) # clean up data  before processing 
+        typ, prop, widths, _class, css_props, attrs = self._parse_params(header)
         
         if typ == "citations" or header.lstrip(' :').startswith("citations"): # both kind of blocks
             pre = '```' if typ == "citations" else '' # correct error message
@@ -516,13 +535,13 @@ class XMarkdown(Markdown):
                 self._wr.write(data, css_class=_class)
             return cap.outputs
         elif typ in ("multicol","columns") and re.search(r'^\+\+\+\s*$', data, flags=re.MULTILINE): # handle columns and multicol with display mode
-            return self._parse_multicol(data, widths, _class) # simple columns will be handled inline 
+            return self._parse_multicol(data, widths, _class, parts) # simple columns will be handled inline 
         elif "md-" in typ:
             return self._parse_md_src(data, header)
         elif typ == "table":
             return self._parse_table(data, widths, _class, css_props, attrs)
         elif typ == "code":
-            return self._parse_code(data, _class, css_props, attrs)
+            return self._parse_code(data, prop, widths, _class, css_props, attrs)
         elif header.strip().startswith(":::") or typ in ("columns","multicol"): # simple flex ```columns without +++ or ::: block
             return self._parse_colon_block(header, data)
         else:
@@ -539,7 +558,7 @@ class XMarkdown(Markdown):
         STRICT_TAGS = ("pre","raw") # code is handled separately
         CAPTURED_TAGS = ("p","details","summary","center","blockquote","ul","ol","nav", *STRICT_TAGS) # tags that are captured by this parser
         
-        tag, widths, _class, css_props, attrs = self._parse_params(header)
+        tag, _, widths, _class, css_props, attrs = self._parse_params(header)
         
         if tag in CAPTURED_TAGS:
             if tag in STRICT_TAGS: # keep as is from further processing
@@ -564,14 +583,24 @@ class XMarkdown(Markdown):
         _class = " ".join([tag, _class, "columns" if tag == "multicol" else ""]) # add columns class if multicol
         return [XTML(f"<div class='{_class}' {_inline_style(css_props)} {attrs}>{self._parse_nested(data, returns=True)}</div>{style}")]
     
-    def _parse_code(self, data, _class, props, attrs):
+    def _parse_code(self, data, prop, focus_lines, _class, props, attrs):
         params = inspect.signature(_highlight).parameters.keys()
         kwargs = {k: eval(v) if v in "TrueFalseNone" else v for k, v in props.items() if k in params} # only pass known params
         out = _highlight(data, css_class=_class, **kwargs)
         leftover = {k: v for k, v in props.items() if k not in params} # left over attributes
         if leftover:
             out = re.sub(r"^<div([^>]*)>", rf"<div\1 {_inline_style(leftover)} {attrs}>",out, count=1)
-        return [XTML(out)]
+        out = SourceCode(out)
+        if focus_lines:
+            lines = lines=[int(l) - 1 for l in focus_lines] # convert to 0-based index for python
+            if min(lines) < 0:
+                return [error('IndexError',f"Focus lines {focus_lines} in markdown code blocks are 1-based index unlike python!")]
+            out = out.focus(lines) 
+        out.raw = textwrap.dedent(data) # attach raw code with even focused lines
+        
+        if prop and getattr(out, prop, None):
+            out = getattr(out, prop) # get property if available
+        return [out]
                 
     def _parse_table(self, data, widths, _class, props, attrs):
         out = self._parse_nested(data, returns=True) # let table extension handle it
@@ -591,38 +620,23 @@ class XMarkdown(Markdown):
         return [XTML(out)] # return table as is, it will be parsed by table extension
         
     def _parse_md_src(self, data, header):
-        pos, *collapse = header.strip(' :')[3:].split() # if ::: md-[suffix] [-c], clean :::
-        _class = ' '.join(collapse[1:] if collapse and collapse[0] == "-c" else collapse)
-        _req_pos = "before,after,left,right"
-        if pos not in _req_pos:
-            return [error("ValueError",f"The suffix after md- should be {_req_pos}, got {pos}")]
-        if collapse and collapse[0] not in ("","-c"):
-            return [error("ValueError",f"Only swicth -c expected if given to collapse code after md-[suffix] other than CSS class, got {collapse[0]}")]
-        src = XTML(_highlight(data, "markdown", name=False if collapse else None, css_class=f"md-src {_class}"))
-        if collapse:
-            src = XTML(f"<details><summary>Show Markdown Source</summary>\n{src}\n</details>")
-        
+        typ, prop, focus_lines, _class, kwargs, attrs = self._parse_params(header) 
+        kwargs["language"] = "markdown" # force markdown language anyhow
+        src, = self._parse_code(data, prop, focus_lines, _class, kwargs, attrs) # list of one item
+        if typ not in ("md-before", "md-after"):  # normal md block
+            self._md_ns[typ[3:]] = src # store variable without md- prefix to have available in processing below
+        outputs = []
+        if "before" in typ: outputs.append(src)
         if self._returns: # display context
-            outs = [XTML(self._parse_nested(data, returns=True))]
+            outputs.append(XTML(self._parse_nested(data, returns=True)))
         else:
             with capture_content() as cap:
                 self._parse_nested(data, returns=False)
-            outs = cap.outputs
-        
-        if pos in ("before","after"):
-            return [src, *outs] if pos == "before" else [*outs, src]
-        
-        if self._returns: 
-            objs = (src, outs[0]) if pos == "left" else (outs[0], src) # return mode, len(outs) == 1
-            output = "\n".join(f"<div style='width:50%;overflow-x:auto;height:auto;position:relative;'>{v}</div>" for v in objs)
-            return [XTML(f'<div class="columns md-block" style="display:flex;">\n{output}\n</div>')] # display for notebook
-        
-        with self.active_parser(),capture_content() as cap:
-            self._wr.write(*((src, outs) if pos == "left" else (outs, src)), css_class="md-block")
-        return cap.outputs
+            outputs.extend(cap.outputs)
+        if "after" in typ: outputs.append(src)
+        return outputs
 
-
-    def _parse_multicol(self, data, widths, _class):
+    def _parse_multicol(self, data, widths, _class, parts):
         "Returns parsed block or columns or code, input is without ``` but includes langauge name."
         cols = re.split(r"^\+\+\+\s*$", data, flags=re.MULTILINE)  # Split by columns, allow nesetd blocks by indents
         if not widths:
@@ -644,16 +658,20 @@ class XMarkdown(Markdown):
         if not self._returns:
             cap_cols = []
             for col in cols:
-                with capture_content() as cap:
-                    self._parse_nested(col,returns=False)
-                cap_cols.append(cap)
+                rows = [] # list to make row-wise parts
+                for row in self._split_parts(col):
+                    with capture_content() as cap:
+                        self._parse_nested(row,returns=False)
+                    rows.append(cap.outputs)
+                cap_cols.append(rows) 
 
             with self.active_parser(), capture_content() as cap:
+                if parts: display(_delim("PART")) # part delimiter for multicol++
                 self._wr.write(*cap_cols, widths=widths, css_class=_class)
             
             return cap.outputs
         
-        cols = [self._parse_nested(col,returns=True) for col in cols]
+        cols = ['\n'.join(self._parse_nested(row,returns=True) for row in self._split_parts(col)) for col in cols]
         if len(cols) == 1: # do not return before checking widths and adding extra cols if needed
             return [XTML(f'<div class={_class}">{cols[0]}</div>' if _class else cols[0])]
 
@@ -667,7 +685,7 @@ class XMarkdown(Markdown):
         """Replaces variables with placeholder after conversion to respect all other extensions.
         Returns str or list of outputs based on context. To ensure str, use `parse(..., returns=True)`.
         """
-        text = resolve_included_files(text)
+        text = resolve_included_files(self, text)
         text = char_esc.escape(text)  # Escape characters before processing
 
         text = self._resolve_nested(text)  # Resolve nested objects in form func`//text//` to func`html_repr`
@@ -752,11 +770,14 @@ class XMarkdown(Markdown):
             def handle_match(match):
                 key,*_ = _matched_vars(match.group()) 
                 # First check if it is an escaped variable
+                esc._store.update(self._md_ns)
                 if key in esc._store: # escaped variable
                     value = esc._store.pop(key) # remove after using once
                     if isinstance(value, DOMWidget) or key.endswith('DISPLAY'): # Anything with display or widget
                         return self._handle_var(value, ctx = match.group())
                     return self._handle_var(hfmtr.vformat(f"{{{match.group()[2:-1].strip()}}}", (), {key: value})) # clear spaces around variable
+                else: # clear md- variables after using once from this store if any left, to avoid clutter
+                    esc._store = {k:v for k, v in esc._store.items() if not k in self._md_ns}
                 
                 if key not in user_ns: # top level var without ., indexing not found
                     err = error('NameError', f'name {key!r} is not defined')
@@ -923,7 +944,7 @@ class xmd(metaclass=_XMDMeta):
     By default, the extensions `tables`, `footnotes`, `attr_list`, `md_in_html`, `def_list` are enabled.
 
     You can add extra markdown extensions using `Slides.xmd.extensions` or `ipyslides.xmd.extensions`.
-    See [markdown extensions](https://python-markdown.github.io/extensions/) for deatails.
+    See [markdown extensions](https://python-markdown.github.io/extensions/) for details.
     
     **Returns**: A direct call or xmd.parse method returns a string with HTML content if `returns=True` (default), otherwise display rich output objects.
     """
